@@ -47,7 +47,7 @@
 #define R__USE_IMT   /**/
 #undef R__COMPLETE_MEM_TERMINATION /**/
 #undef R__HAS_CEFWEB  /**/
-#undef R__HAS_QT5WEB  /**/
+#undef R__HAS_QT6WEB  /**/
 #define R__HAS_DAVIX  /**/
 #define R__HAS_DATAFRAME /**/
 #define R__HAS_ROOT7 /**/
@@ -69,8 +69,8 @@
 #define R__HAS_TMVACPU /**/
 #undef R__HAS_TMVAGPU /**/
 #undef R__HAS_CUDNN /**/
-#define R__HAS_PYMVA /**/
-#undef R__HAS_RMVA /**/
+#undef R__HAS_PYMVA /**/
+#define R__HAS_RMVA /**/
 
 #undef R__HAS_URING /**/
 
